@@ -1,8 +1,10 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
+from distutils.version import LooseVersion
 
 import pytest
+from selenium import __version__ as SELENIUM_VERSION
 from selenium.webdriver.chrome.options import Options
 
 
@@ -10,7 +12,14 @@ def driver_kwargs(capabilities, driver_args, driver_log, driver_path,
                   chrome_options, **kwargs):
     kwargs = {
         'desired_capabilities': capabilities,
-        'chrome_options': chrome_options}
+    }
+
+    # Selenium 3.8.0 deprecated chrome_options in favour of options
+    if LooseVersion(SELENIUM_VERSION) < LooseVersion('3.8.0'):
+        kwargs['chrome_options'] = chrome_options
+    else:
+        kwargs['options'] = chrome_options
+
     if driver_args is not None:
         kwargs['service_args'] = driver_args
     if driver_log is not None:
